---
title: 'HOSR Core Rules: Magic'
description:
date_pub: 2023-04-22T16:42:00-04:00
section: rules
content_type: feature
short_code: uhm
---

[[toc]]

### Magic & Spells

Spells are patterns of energy that can be manipulated and used by some characters to alter reality to their will.

When reality is altered this way, it's called magic, and the characters who can do it are known as spellcasters.

Each spellcasting class has an associated type of magic: arcane, divine, eldritch, or psychic.

There's an additional class of spells known as rituals, which have their own requirements, and (in many cases) need not be performed by a spellcaster.

### Memorizing Spells

Takes one hour, can only be done once per day.

-   A character’s level determines how many spells they can memorize at one time.
-   The same spell may be memorized more than once, if the character can memorize more than one spell of that level.

### Casting Spells

Memorized spells are cast by replicating necessary hand gestures and spoken words.

-   When a spell is cast, it is erased from the caster's mind.
-   The caster must be able to speak and move their hands freely (ex: can't be gagged, bound, or magically silenced).
-   The target (a specific monster, character, object, or area of effect) must be visible to the caster (unless stated otherwise).
-   The caster must have one hand free (or a magic item in one hand).

Ritual spells may be cast by performing the ritual as described.

### Spell Effects

-   Some spells affect multiple targets, either by area or by Hit Dice total. If the spell doesn't say how to select the targets, the referee decides.
-   Some spells require **concentration**.
    -   These spells require the caster's focus to maintain the spell's effect.
    -   Performing any other action (moving or attacking) causes concentration to end.
    -   When distracted (ex: damaged by a spell or weapon) while concentrating, the spellcaster must make a Willpower check (highest of CHA or CON), with a penalty of 1/2 the damage inflicted (to a max of -4), or the spell ends.
-   Multiple spells cannot increase the same ability (e.g. bonuses to attack rolls, AC, damage rolls, saving throws, etc.).
    -   Spells that affect different abilities can be combined.
    -   Spells can also be combined with the effects of magical items.

### Magical Research

New spells may be found and learned (or created) via research.

-   Requires access to information (ex: library, other spellbooks, etc.) .
-   Takes 2 weeks, and 1000 standard coins per spell level.
-   All spell casters are assumed to be able to perform magical research.

### Alchemy

Alchemical formulas (for brewing potions and such) can be learned and used by anyone with access to the proper equipment.

-   Some arcane spellcasters store learned alchemical formulae within their spellbooks.
-   The difficulty with most potions is not in the brewing, but in acquiring the ingredients (and/or the correct formula).

### Arcane Magic

Arcane magic comes from written spells, formulae, and procedures known to alter reality.

-   Arcane spellcasters memorize spells from their spell books, which must be close at hand.
-   If a spell can be reversed, its form must be selected when the spell is memorized
    -   Both forms can be memorized if the character can memorize more than one spell of the given level.
-   Spells may be learned from a higher-level mentor (1 week / spell), copied from a scroll or spellbook with the Read Magic spell, or from research.
-   Lost spell books can be rebuilt spell-by-spell, with each spell taking 1 week of game time and 500 standard coins per spell level.
-   Arcane spells written by other spellcasters can only be translated by the Read Magic spell.
-   Arcane casters can use arcane magic items and scrolls.

<div class="dividedTableWrapper">

|  INT  | SS  | CC  |
| :---: | :-: | :-: |
|   3   |  1  | 20  |
|  4-5  |  1  | 30  |
|  6-7  |  2  | 40  |
|  8-9  |  2  | 50  |
| 10-11 |  3  | 60  |
| 12-13 |  3  | 70  |
| 14-15 |  4  | 80  |
| 16-17 |  5  | 90  |
|  18+  |  6  | 95  |

</div>

-   **Starting Spells (SS)**: The number of starting spells in a new caster's spell book.
-   **Copy Chance (CC)**: The chance to _perfectly_ copy spells scrolls and other sources into spellbook. Referee rolls 1d100, result under score is success, failure means an interesting side effect occurs when the spell is cast (must wait until next XP level to try again).

### Divine Magic

Divine magic comes from a spellcaster's connection to one or more gods.

-   Divine spellcasters memorize spells through prayer to their gods.
    -   When praying for spells, they may choose any spells in their class’ spell list that they are of high enough level to cast.
-   Divine casters must be faithful to the tenets of their alignment, clergy, and religion.
    -   If they ever fall out of favor with their deity, penalties may be imposed (ex: -1 to attack, a reduction in spells, or being sent on a perilous quest).
    -   To regain favor, they would need to perform a great deed for their deity (referee's choice - ex: donating relics or gold, building a temple, converting others to the religion, etc.).
-   Divine casters can cast reversed versions of spells (possibly gaining deity disfavor).
    -   **Lawful characters**: Only use reversed spells in dire circumstances.
    -   **Chaotic characters**: Usually use reversed spells, only using normal spell versions to benefit their allies.
    -   **Neutral characters**: Usually favor either normal or reversed spells, depending on the deity.
-   Divine casters can use divine magic items and scrolls.

### Eldritch Magic

Eldritch magic comes from special pacts made between the spellcaster and one or more ancient, powerful beings.

-   Eldritch spellcasters memorize spells through the use of ritual invocations to their patrons.
    -   When memorizing spells, eldritch magicians may choose any spells in their class’ spell list that they are of high enough level to cast.
-   Eldritch casters must be faithful to their patron.
    -   If they ever fall out of favor with their patron, penalties may be imposed (ex: -1 to eldritch blast damage, a reduction in spells, or being sent on a perilous quest).
    -   To regain favor, they would need to perform a great deed for their patron (referee's choice - ex: collecting an artifact, constructing an altar, vanquishing a powerful enemy of the patron, etc.).
-   Eldritch casters can cast reversed versions of spells.
-   Eldritch casters can use arcane magic items and scrolls.

### Psychic Magic (WIP)

Psychic magic comes from a spellcaster's innate ability to alter reality, even if they can't fully control it.

-   Psychic spellcasters begin each day with each of their spells memorized.
-   To cast a spell, a psychic caster must roll 1d20 + the highest of INT or CHA.
    -   On a natural 1, the spell fizzles and is expended, [backlash](#backlash) occurs, and the next casting of a psychic spell gets -2.
    -   On a 2-6, the spell fizzles without being expended.
    -   On a 7-15, the spell succeeds as per normal.
    -   On a 16+, the spell succeeds in notable manner as determined by referee (ex: double duration, range, or targets).
    -   On a 20+ (or a natural 20), the spell succeeds as well as possible (player chooses up to two effects from above, possibly without expending spell), and the next casting of a psychic spell gets +2.
-   Psychic casters can cast reversed versions of spells.
-   Psychic casters can use arcane magic items and scrolls.

#### Backlash

Roll 1d20 on the Backlash Table to see what effect occurs.

<div class="dividedTableWrapper">

| 1dXX |                                            Effect                                            |
| :--: | :------------------------------------------------------------------------------------------: |
|  1   |                                       Fall unconscious                                       |
|  2   | [Black Tentacles](/spells/black-tentacles.html) appear in 20' square area centered on caster |
|  3   |                                       Take 1d8 damage                                        |
|  4   |                           All creatures within 30' take 1d6 damage                           |
|  5   |                           All creatures within 20' take 1d6 damage                           |
|  6   |                           All creatures within 10' take 1d6 damage                           |
|  7   |                  Cursed, -1 to any attempt to cast for the rest of the day                   |
|  8   |                          **Save vs Spells** or flee for 1d4 minutes                          |
|  9   |                     Migraine, can't attack, move, or cast for 1d4 rounds                     |
|  10  |                             Panicked, can't cast for 1d4 rounds                              |
|  11  |                Spell casts but target changes to a random target within range                |
|  12  |                   Spell casts but effect rebounds onto caster instead[^1]                    |
|  13  |                       Discombobulated, can't cast spells for 1d4 hours                       |
|  14  |        See hallucinations (illusory monsters, horrifying visions, etc) for 1d4 rounds        |
|  15  |                 Dumbfounded, lose ability to speak coherently for 1d4 hours                  |
|  16  |                  Distressed, next attempt to cast today gets additional -2                   |
|  17  |                  Befuddled, lose ability to speak coherently for 1d4 turns                   |
|  18  |                         Distracted, go last in initiative next round                         |
|  19  |                      Temporary loss of motor skills, fall down (prone)                       |
|  20  |                                     No additional effect                                     |

</div>

[^1]: If the caster was the target, effect rebounds onto another random target within range or 10', whichever is greater.

### Ritual Magic

Ritual spells may be cast without being memorized / granted through prayer or supplication.

-   Ritual spells are often complicated, taking several minutes (or turns) to cast.
-   Rituals are many and varied - some can even be performed by non-spellcasters (with proper instruction).
-   The power of the ritual is based on several factors, including:
    -   The time spent casting the ritual (with longer rituals being more powerful),
    -   Any sacrifices made as part of the ritual (with willing and/or virginal sacrifices yielding more power), and
    -   Any components used during the ritual (with more powerful rituals requiring rarer or more difficult to obtain components).

### Magic Saves

Saving throws versus magical effects get an additional modifier, based on the character's Wisdom.

<div class="dividedTableWrapper">

|  WIS  | Mod |
| :---: | :-: |
|   3   | -3  |
|  4-5  | -2  |
|  6-8  | -1  |
| 9-12  | +0  |
| 13-15 | +1  |
| 16-17 | +2  |
|  18+  | +3  |

</div>

!!!include(license/wotc-cc-by.md)!!!
